/***********************************************************************/
/*                                                                     */
/*         USE THE CROSS-SECTIONAL FILE FOR THE 1998 HEALTH COMPONENT  */
/*         (DUMYH356.TXT)                                              */
/*         TO STUDY THE RELATION BETWEEN CHRONIC CONDITION REPORTING   */
/*         AND THE TYPE OF INTERVIEW (PROXY VS NON-PROXY)              */
/*                                                                     */
/***********************************************************************/

libname in1 'c:\data';

data in1.dumyh356;
  %let datafid="c:\data\dumyh356.txt";
  %include "c:\data\h356_i.sas";
  keep realukey personid dhc8_age dhc8_sex am58_pxy ccc8dany
  age1217 age1820 age2124 age2534 age3544 age4554 age5564
  age6574 age7584 age85 female nonproxy wt68;
  if dhc8_age >= 12;

/* Dummy variables for the age group */

  age1217=0;
  age1820=0;
  age2124=0;
  age2534=0;
  age3544=0;
  age4554=0;
  age5564=0;
  age6574=0;
  age7584=0;
  age85=0;

  if 12 <= dhc8_age <=17 then age1217=1;
  if 18 <= dhc8_age <=20 then age1820=1;
  if 21 <= dhc8_age <=24 then age2124=1;
  if 25 <= dhc8_age <=34 then age2534=1;
  if 35 <= dhc8_age <=44 then age3544=1;
  if 45 <= dhc8_age <=54 then age4554=1;
  if 55 <= dhc8_age <=64 then age5564=1;
  if 65 <= dhc8_age <=74 then age6574=1;
  if 75 <= dhc8_age <=84 then age7584=1;
  if dhc8_age>=85 then age85=1;

  female=0;
  if dhc8_sex=2 then female=1;

/* Missing values */

  if ccc8dany>2 then ccc8dany=.;
  if ccc8dany=2 then ccc8dany=0;

  nonproxy=0;
  if am58_pxy>2 then nonproxy=.;
  if am58_pxy=2 then nonproxy=1;
run;

proc logistic data=in1.dumyh356 descending;
     model ccc8dany = nonproxy age1820 age2124 age2534 age3544
       age4554 age5564 age6574 age7584 age85 female;
     weight wt68;
title 'Chronic conditions';
run;
